# Table of Contents

- [onboarding-journey](<./onboarding-journey.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Onboarding Journey](<./Onboarding-Journey.md>)
  - [Overview](<./Onboarding-Journey/Overview.md>)
  - [What You'll Achieve](<./Onboarding-Journey/What-Youll-Achieve.md>)
  - [How to Get Started](<./Onboarding-Journey/How-to-Get-Started.md>)
  - [Who to Involve](<./Onboarding-Journey/Who-to-Involve.md>)
  - [Resources and Support](<./Onboarding-Journey/Resources-and-Support.md>)
  - [Was this page helpful?](<./Onboarding-Journey/Was-this-page-helpful.md>)
